/**
 *
 */
package org.gcube.portlets.widgets.ckancontentmoderator.client.ui;

import org.gcube.portlets.widgets.ckancontentmoderator.client.events.IFrameInstanciedEvent;
import org.gcube.portlets.widgets.ckancontentmoderator.client.events.IFrameInstanciedEvent.OPERATION;
import org.gcube.portlets.widgets.ckancontentmoderator.client.resources.ContentModeratorWidgetResources;

import com.google.gwt.core.shared.GWT;
import com.google.gwt.dom.client.Style.Display;
import com.google.gwt.dom.client.Style.Unit;
import com.google.gwt.event.dom.client.LoadEvent;
import com.google.gwt.event.dom.client.LoadHandler;
import com.google.gwt.event.shared.HandlerManager;
import com.google.gwt.http.client.URL;
import com.google.gwt.user.client.Random;
import com.google.gwt.user.client.ui.FlowPanel;
import com.google.gwt.user.client.ui.Frame;
import com.google.gwt.user.client.ui.Image;
import com.google.gwt.user.client.ui.NamedFrame;

/**
 * The Class CkanInternalFramePanel.
 *
 * @author Francesco Mangiacrapa at ISTI-CNR francesco.mangiacrapa@isti.cnr.it
 * 
 *         Feb 25, 2022
 */
public class CkanInternalFramePanel extends FlowPanel {

	private NamedFrame namedFrame;
	private HandlerManager eventBus;
	private Image loading = new Image(ContentModeratorWidgetResources.ICONS.loading());
	private String messageToSend;
	private String iFrameRandomName;

	/**
	 * Instantiates a new ckan namedFrame panel.
	 *
	 * @param eventBus the event bus
	 */
	public CkanInternalFramePanel(HandlerManager eventBus) {
		this.eventBus = eventBus;
		addLoading();
	}

	/**
	 * Prints the.
	 *
	 * @param msg the msg
	 */
	private static native void print(String msg)/*-{
		console.log(msg);
	}-*/;

	/**
	 * Instance namedFrame.
	 *
	 * @param datasetURL the dataset URL
	 * @return the namedFrame
	 */
	public Frame instanceFrame(String datasetURL) {
		GWT.log("Instancing new IFRAME with uri: " + datasetURL);
		addLoading();
		String urlEncoded = URL.encode(datasetURL);
		GWT.log("Encoded url for instanciating namedFrame is " + urlEncoded);
		iFrameRandomName = Random.nextInt() + "dataset-internal-iframe" + Random.nextInt();
		namedFrame = new NamedFrame(iFrameRandomName);
		namedFrame.setUrl(urlEncoded);

		namedFrame.getElement().setId(iFrameRandomName);
		namedFrame.setWidth("100%");
		namedFrame.setHeight("580px");
		namedFrame.getElement().getStyle().setBorderWidth(0, Unit.PX);
		namedFrame.addLoadHandler(new LoadHandler() {

			@Override
			public void onLoad(LoadEvent arg0) {

				CkanInternalFramePanel.this.remove(loading);
				eventBus.fireEvent(new IFrameInstanciedEvent(namedFrame, OPERATION.ONLOAD));
			}
		});
		add(namedFrame);
		namedFrame.setVisible(true);
		eventBus.fireEvent(new IFrameInstanciedEvent(namedFrame, OPERATION.INIT));
		return namedFrame;
	}

	/**
	 * Gets the namedFrame.
	 *
	 * @return the namedFrame
	 */
	public Frame getFrame() {
		return namedFrame;
	}

	/**
	 * add loading image.
	 */
	private void addLoading() {
		this.add(loading);
		loading.getElement().getStyle().setProperty("margin", "auto");
		loading.getElement().getStyle().setDisplay(Display.BLOCK);
	}
}
